==> bellsoft-jdk21.0.9+11-src-full.tar.gz: jdk-21.0.9-full/openjfx/modules/javafx.graphics/src/test/java/test/com/sun/javafx/css/BooleanTypeTest.java <==
/*
 * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package test.com.sun.javafx.css;

import com.sun.javafx.css.ParsedValueImpl;
import static org.junit.Assert.assertEquals;
import javafx.css.ParsedValue;
import javafx.scene.text.Font;

import org.junit.Test;

import javafx.css.converter.BooleanConverter;


public class BooleanTypeTest {

    public BooleanTypeTest() {
    }

    /**
     * Test of convert method, of class BooleanType.
     */
    @Test
    public void testConvert() {
        //System.out.println("convert");
        Font font = null;

        ParsedValue< String,Boolean> value = new ParsedValueImpl<>("true", BooleanConverter.getInstance());
        Boolean expResult = Boolean.TRUE;
        Boolean result = value.convert(font);
        assertEquals(expResult, result);

        value = new ParsedValueImpl<>("false", BooleanConverter.getInstance());
        expResult = Boolean.FALSE;
        result = value.convert(font);
        assertEquals(expResult, result);

        value = new ParsedValueImpl<>(null, BooleanConverter.getInstance());
        expResult = Boolean.FALSE;
        result = value.convert(font);
        assertEquals(expResult, result);

    }

}

==> bellsoft-jdk25.0.1+11-src-full.tar.gz: jdk-25.0.1-full/openjfx/modules/javafx.graphics/src/test/java/test/com/sun/javafx/css/BooleanTypeTest.java <==
/*
 * Copyright (c) 2010, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package test.com.sun.javafx.css;

import com.sun.javafx.css.ParsedValueImpl;
import javafx.css.ParsedValue;
import javafx.scene.text.Font;

import org.junit.jupiter.api.Test;
import static org.junit.jupiter.api.Assertions.assertEquals;

import javafx.css.converter.BooleanConverter;


public class BooleanTypeTest {

    public BooleanTypeTest() {
    }

    /**
     * Test of convert method, of class BooleanType.
     */
    @Test
    public void testConvert() {
        //System.out.println("convert");
        Font font = null;

        ParsedValue< String,Boolean> value = new ParsedValueImpl<>("true", BooleanConverter.getInstance());
        Boolean expResult = Boolean.TRUE;
        Boolean result = value.convert(font);
        assertEquals(expResult, result);

        value = new ParsedValueImpl<>("false", BooleanConverter.getInstance());
        expResult = Boolean.FALSE;
        result = value.convert(font);
        assertEquals(expResult, result);

        value = new ParsedValueImpl<>(null, BooleanConverter.getInstance());
        expResult = Boolean.FALSE;
        result = value.convert(font);
        assertEquals(expResult, result);

    }

}
